A simple utility for using docker compose (ideally from the repl).
A simple utility for using docker compose (ideally from the repl).
(compose-down)(compose-up)(is-port-bound? port)(is-running? container-name)Check if the named container is running - i.e it has a status of "running" provided by docker ps
Check if the named container is running - i.e it has a status of "running" provided by docker ps
(wait-for pred interval-ms timeout-ms)(wait-for pred interval-ms timeout-ms wait-ms)Wait for a given predicate to become true. Returns true if the predicate returns true, otherwise returns false when the timeout is reached
Wait for a given predicate to become true. Returns true if the predicate returns true, otherwise returns false when the timeout is reached
(wait-for-container container-name)(wait-for-container container-name interval-ms)(wait-for-container container-name interval-ms timeout-ms)Waits for the given container name to reach a state of "running"
Waits for the given container name to reach a state of "running"
(wait-for-port port)(wait-for-port port interval-ms)(wait-for-port port interval-ms timeout-ms)Waits for the given port to be bound
Waits for the given port to be bound
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |